var __defProp = Object.defineProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};

// src/Adaptor.js
var Adaptor_exports = {};
__export(Adaptor_exports, {
  alterState: () => alterState,
  arrayToString: () => arrayToString,
  as: () => as,
  combine: () => combine,
  cursor: () => cursor,
  dataPath: () => dataPath,
  dataValue: () => dataValue,
  dateFns: () => dateFns,
  each: () => each,
  execute: () => execute,
  field: () => field,
  fields: () => fields,
  fn: () => fn,
  fnIf: () => fnIf,
  insert: () => insert,
  lastReferenceValue: () => lastReferenceValue,
  merge: () => merge,
  sourceValue: () => sourceValue,
  sql: () => sql,
  upsert: () => upsert,
  upsertMany: () => upsertMany
});
import { execute as commonExecute } from "@openfn/language-common";
import { expandReferences } from "@openfn/language-common/util";
import mysql from "mysql";
import squel from "squel";
import {
  fn,
  fnIf,
  each,
  merge,
  field,
  fields,
  cursor,
  dateFns,
  combine,
  dataPath,
  dataValue,
  alterState,
  sourceValue,
  arrayToString,
  lastReferenceValue,
  as
} from "@openfn/language-common";
function sql(sqlQuery, options = {}) {
  return (state) => {
    const { connection } = state;
    const [resolvedSqlQuery, resolvedOptions] = expandReferences(
      state,
      sqlQuery,
      options
    );
    const { writeSql = false, execute: execute2 = true } = resolvedOptions;
    if (writeSql) {
      console.log("Prepared SQL:", resolvedSqlQuery);
    }
    if (!execute2) {
      return {
        ...state,
        queries: [...state.queries || [], resolvedSqlQuery]
      };
    }
    return new Promise((resolve, reject) => {
      connection.query(resolvedSqlQuery, (err, results, fields2) => {
        if (err) {
          console.log("Error executing query. Disconnecting from database.");
          connection.end();
          return reject(err);
        }
        resolve({ ...state, response: { body: results, fields: fields2 } });
      });
    });
  };
}
function execute(...operations) {
  const initialState = {
    references: [],
    data: null
  };
  return (state) => {
    return commonExecute(
      connect,
      ...operations,
      disconnect,
      cleanupState
    )({ ...initialState, ...state });
  };
}
function connect(state) {
  const { host, port, database, password, user } = state.configuration;
  var connection = mysql.createConnection({
    host,
    user,
    password,
    database,
    port
  });
  connection.connect();
  console.log(`Preparing to query "` + database + `"...`);
  return { ...state, connection };
}
function disconnect(state) {
  state.connection.end();
  return state;
}
function cleanupState(state) {
  delete state.connection;
  return state;
}
function insert(table, fields2) {
  return (state) => {
    let { connection } = state;
    const [valuesObj] = expandReferences(state, fields2);
    const squelMysql = squel.useFlavour("mysql");
    var sqlParams = squelMysql.insert({
      autoQuoteFieldNames: true
    }).into(table).setFields(valuesObj).toParam();
    const sql2 = sqlParams.text;
    const inserts = sqlParams.values;
    const sqlString = mysql.format(sql2, inserts);
    console.log(`Executing MySQL query: ${sqlString}`);
    return new Promise((resolve, reject) => {
      connection.query(sqlString, function(err, results, fields3) {
        if (err) {
          reject(err);
          console.log("There is an error. Disconnecting from database.");
          connection.end();
        } else {
          console.log("Success...");
          console.log(results);
          console.log(fields3);
          resolve(results);
        }
      });
    }).then((data) => {
      const nextState = { ...state, response: { body: data } };
      return nextState;
    });
  };
}
function upsert(table, fields2) {
  return (state) => {
    let { connection } = state;
    const [valuesObj] = expandReferences(state, fields2);
    const squelMysql = squel.useFlavour("mysql");
    var insertParams = squelMysql.insert({
      autoQuoteFieldNames: true
    }).into(table).setFields(valuesObj).toParam();
    var sql2 = insertParams.text;
    var inserts = insertParams.values;
    const insertString = mysql.format(sql2, inserts);
    var updateParams = squelMysql.update({
      autoQuoteFieldNames: true
    }).table("").setFields(valuesObj).toParam();
    var sql2 = updateParams.text;
    var inserts = updateParams.values;
    const updateString = mysql.format(sql2, inserts);
    const upsertString = insertString + ` ON DUPLICATE KEY UPDATE ` + updateString.slice(10);
    console.log("Executing MySQL query: " + upsertString);
    return new Promise((resolve, reject) => {
      connection.query(upsertString, function(err, results, fields3) {
        if (err) {
          reject(err);
          console.log("That's an error. Disconnecting from database.");
          connection.end();
        } else {
          console.log("Success...");
          console.log(results);
          console.log(fields3);
          resolve(results);
        }
      });
    }).then((data) => {
      const nextState = { ...state, response: { body: data } };
      return nextState;
    });
  };
}
function upsertMany(table, data) {
  return function(state) {
    return new Promise(function(resolve, reject) {
      const [rows] = expandReferences(state, data);
      if (!rows || rows.length === 0) {
        console.log("No records provided; skipping upsert.");
        resolve(state);
      }
      const squelMysql = squel.useFlavour("mysql");
      const columns = Object.keys(rows[0]);
      let upsertSql = squelMysql.insert().into(table).setFieldsRows(rows);
      columns.map((c) => {
        upsertSql = upsertSql.onDupUpdate(`${c}=values(${c})`);
      });
      const upsertString = upsertSql.toString();
      let { connection } = state;
      connection.query(upsertString, function(err, results, fields2) {
        if (err) {
          reject(err);
          console.log("That's an error. Disconnecting from database.");
          connection.end();
        } else {
          console.log("Success...");
          console.log(results);
          console.log(fields2);
          resolve(results);
        }
      });
    }).then(function(data2) {
      const nextState = { ...state, response: { body: data2 } };
      return nextState;
    });
  };
}

// src/index.js
var src_default = Adaptor_exports;
export {
  alterState,
  arrayToString,
  as,
  combine,
  cursor,
  dataPath,
  dataValue,
  dateFns,
  src_default as default,
  each,
  execute,
  field,
  fields,
  fn,
  fnIf,
  insert,
  lastReferenceValue,
  merge,
  sourceValue,
  sql,
  upsert,
  upsertMany
};
